@@ -17,13 +17,22 @@ class Sheet(Base):
     # Идентификатор
     id = Column('sheet_id', Integer, primary_key=True)
 
+    # Статус
+    status = Column(Integer)
+
     # Тип ведомости
     sheet_type_id = Column(ForeignKey('univer_sheet_type.sheet_type_id'))
     sheet_type = relationship('SheetType')
 
+    # Дата создания
+    date_create = Column(DateTime)
+
     # Дата и время закрытия
     date_keep = Column(DateTime)
 
+    # Дата проведения
+    date_control = Column(DateTime)
+
     # Группа
     group_id = Column(ForeignKey('univer_group.group_id'))
     group = relationship('Group')
